@@ -18,6 +18,7 @@
 #
 # ------------------------------------------------------------------------------
 """Cosmos module wrapping the public and private key cryptography and ledger api."""
+# pylint: disable = import-outside-toplevel, possibly-unused-variable
 import base64
 import gzip
 import hashlib
@@ -38,37 +39,6 @@ from bech32 import (  # pylint: disable=wrong-import-order
     bech32_encode,
     convertbits,
 )
-from cosmpy.auth.rest_client import AuthRestClient
-from cosmpy.bank.rest_client import BankRestClient, QueryBalanceRequest
-from cosmpy.common.rest_client import RestClient
-from cosmpy.cosmwasm.rest_client import CosmWasmRestClient
-from cosmpy.protos.cosmos.auth.v1beta1.auth_pb2 import BaseAccount
-from cosmpy.protos.cosmos.auth.v1beta1.query_pb2 import QueryAccountRequest
-from cosmpy.protos.cosmos.bank.v1beta1.tx_pb2 import MsgSend
-from cosmpy.protos.cosmos.base.v1beta1.coin_pb2 import Coin
-from cosmpy.protos.cosmos.crypto.secp256k1.keys_pb2 import PubKey as ProtoPubKey
-from cosmpy.protos.cosmos.tx.signing.v1beta1.signing_pb2 import SignMode
-from cosmpy.protos.cosmos.tx.v1beta1.service_pb2 import (
-    BroadcastMode,
-    BroadcastTxRequest,
-    GetTxRequest,
-)
-from cosmpy.protos.cosmos.tx.v1beta1.tx_pb2 import (
-    AuthInfo,
-    Fee,
-    ModeInfo,
-    SignDoc,
-    SignerInfo,
-    Tx,
-    TxBody,
-)
-from cosmpy.protos.cosmwasm.wasm.v1.query_pb2 import QuerySmartContractStateRequest
-from cosmpy.protos.cosmwasm.wasm.v1.tx_pb2 import (
-    MsgExecuteContract,
-    MsgInstantiateContract,
-    MsgStoreCode,
-)
-from cosmpy.tx.rest_client import TxRestClient
 from ecdsa import (  # type: ignore # pylint: disable=wrong-import-order
     SECP256k1,
     SigningKey,
@@ -88,6 +58,44 @@ from aea.helpers import http_requests as requests
 from aea.helpers.base import try_decorator
 
 
+def lazy_load():  # Python caches all imported modules
+    """Temporary solution because of protos mismatch."""
+    # pylint: disable=import-error
+    from cosmpy.auth.rest_client import AuthRestClient
+    from cosmpy.bank.rest_client import BankRestClient, QueryBalanceRequest
+    from cosmpy.common.rest_client import RestClient
+    from cosmpy.cosmwasm.rest_client import CosmWasmRestClient
+    from cosmpy.protos.cosmos.auth.v1beta1.auth_pb2 import BaseAccount
+    from cosmpy.protos.cosmos.auth.v1beta1.query_pb2 import QueryAccountRequest
+    from cosmpy.protos.cosmos.bank.v1beta1.tx_pb2 import MsgSend
+    from cosmpy.protos.cosmos.base.v1beta1.coin_pb2 import Coin
+    from cosmpy.protos.cosmos.crypto.secp256k1.keys_pb2 import PubKey as ProtoPubKey
+    from cosmpy.protos.cosmos.tx.signing.v1beta1.signing_pb2 import SignMode
+    from cosmpy.protos.cosmos.tx.v1beta1.service_pb2 import (
+        BroadcastMode,
+        BroadcastTxRequest,
+        GetTxRequest,
+    )
+    from cosmpy.protos.cosmos.tx.v1beta1.tx_pb2 import (
+        AuthInfo,
+        Fee,
+        ModeInfo,
+        SignDoc,
+        SignerInfo,
+        Tx,
+        TxBody,
+    )
+    from cosmpy.protos.cosmwasm.wasm.v1.query_pb2 import QuerySmartContractStateRequest
+    from cosmpy.protos.cosmwasm.wasm.v1.tx_pb2 import (
+        MsgExecuteContract,
+        MsgInstantiateContract,
+        MsgStoreCode,
+    )
+    from cosmpy.tx.rest_client import TxRestClient
+
+    return locals()
+
+
 _default_logger = logging.getLogger(__name__)
 
 _COSMOS = "cosmos"
@@ -128,7 +136,7 @@ class DataEncrypt:
         password: str, salt: Optional[bytes] = None
     ) -> Tuple[bytes, bytes]:
         salt = salt or get_random_bytes(16)
-        key = scrypt(password, salt, 16, N=2 ** 14, r=8, p=1)  # type: ignore
+        key = scrypt(password, salt, 16, N=2**14, r=8, p=1)  # type: ignore
         return key, salt  # type: ignore
 
     @classmethod
@@ -276,7 +284,11 @@ class CosmosHelper(Helper):
 
     @staticmethod
     def is_transaction_valid(
-        tx: JSONLike, seller: Address, client: Address, tx_nonce: str, amount: int,
+        tx: JSONLike,
+        seller: Address,
+        client: Address,
+        tx_nonce: str,
+        amount: int,
     ) -> bool:
         """
         Check whether a transaction is valid or not.
@@ -367,7 +379,10 @@ class CosmosHelper(Helper):
         """
         signature_b64 = base64.b64decode(signature)
         verifying_keys = VerifyingKey.from_public_key_recovery(
-            signature_b64, message, SECP256k1, hashfunc=hashlib.sha256,
+            signature_b64,
+            message,
+            SECP256k1,
+            hashfunc=hashlib.sha256,
         )
         public_keys = [
             verifying_key.to_string("compressed").hex()
@@ -509,7 +524,9 @@ class CosmosCrypto(Crypto[SigningKey]):
         :return: signature of the message in string form
         """
         signature_compact = self.entity.sign_deterministic(
-            message, hashfunc=hashlib.sha256, sigencode=sigencode_string_canonize,
+            message,
+            hashfunc=hashlib.sha256,
+            sigencode=sigencode_string_canonize,
         )
         signature_base64_str = base64.b64encode(signature_compact).decode("utf-8")
         return signature_base64_str
@@ -521,7 +538,9 @@ class CosmosCrypto(Crypto[SigningKey]):
         :param transaction: the transaction to be signed
         :return: signed transaction
         """
-
+        Tx, ProtoPubKey, SignDoc = (
+            lazy_load()[k] for k in ("Tx", "ProtoPubKey", "SignDoc")
+        )
         tx = ParseDict(transaction["tx"], Tx())
 
         # If public key is not already part of transaction
@@ -599,6 +618,16 @@ class _CosmosApi(LedgerApi):
 
     def __init__(self, **kwargs: Any) -> None:
         """Initialize the Cosmos ledger APIs."""
+        RestClient, TxRestClient, AuthRestClient, CosmWasmRestClient, BankRestClient = (
+            lazy_load()[k]
+            for k in (
+                "RestClient",
+                "TxRestClient",
+                "AuthRestClient",
+                "CosmWasmRestClient",
+                "BankRestClient",
+            )
+        )
         self._api = None
         self.network_address = kwargs.pop("address", DEFAULT_ADDRESS)
         self.denom = kwargs.pop("denom", DEFAULT_CURRENCY_DENOM)
@@ -624,6 +653,7 @@ class _CosmosApi(LedgerApi):
         logger_method=_default_logger.warning,
     )
     def _try_get_balance(self, address: Address) -> Optional[int]:
+        QueryBalanceRequest = lazy_load()["QueryBalanceRequest"]
         res = self.bank_client.Balance(
             QueryBalanceRequest(address=address, denom=self.denom)
         )
@@ -783,6 +813,7 @@ class _CosmosApi(LedgerApi):
         :param memo: any string comment.
         :return: the unsigned CosmWasm contract deploy message
         """
+        MsgStoreCode, Coin = (lazy_load()[k] for k in ("MsgStoreCode", "Coin"))
         store_msg = MsgStoreCode(
             sender=str(deployer_address),
             wasm_byte_code=base64.b64decode(contract_interface[_BYTECODE]),
@@ -837,6 +868,9 @@ class _CosmosApi(LedgerApi):
         :param memo: any string comment.
         :return: the unsigned CosmWasm InitMsg
         """
+        MsgInstantiateContract, Coin = (
+            lazy_load()[k] for k in ("MsgInstantiateContract", "Coin")
+        )
         if amount == 0:
             init_funds = []
         else:
@@ -898,6 +932,9 @@ class _CosmosApi(LedgerApi):
         :param tx_fee_denom: Denomination of tx_fee, identical with denom param when None
         :return: the unsigned CosmWasm HandleMsg
         """
+        MsgExecuteContract, Coin = (
+            lazy_load()[k] for k in ("MsgExecuteContract", "Coin")
+        )
         denom = denom if denom is not None else self.denom
         chain_id = chain_id if chain_id is not None else self.chain_id
         tx_fee_denom = tx_fee_denom if tx_fee_denom is not None else denom
@@ -963,6 +1000,7 @@ class _CosmosApi(LedgerApi):
         :param query_msg: QueryMsg in JSON format.
         :return: the message receipt
         """
+        QuerySmartContractStateRequest = lazy_load()["QuerySmartContractStateRequest"]
         request = QuerySmartContractStateRequest(
             address=contract_address, query_data=json.dumps(query_msg).encode("UTF8")
         )
@@ -1003,6 +1041,7 @@ class _CosmosApi(LedgerApi):
         :param kwargs: keyword arguments.
         :return: the transfer transaction
         """
+        MsgSend, Coin = (lazy_load()[k] for k in ("MsgSend", "Coin"))
         denom = denom if denom is not None else self.denom
         chain_id = chain_id if chain_id is not None else self.chain_id
         tx_fee_denom = tx_fee_denom if tx_fee_denom is not None else denom
@@ -1056,6 +1095,9 @@ class _CosmosApi(LedgerApi):
 
         :return: Packed MsgExecuteContract
         """
+        MsgExecuteContract, Coin = (
+            lazy_load()[k] for k in ("MsgExecuteContract", "Coin")
+        )
         denom = denom if denom is not None else self.denom
 
         if funds == 0:
@@ -1091,6 +1133,7 @@ class _CosmosApi(LedgerApi):
 
         :return: packer ProtoAny type message
         """
+        MsgSend, Coin = (lazy_load()[k] for k in ("MsgSend", "Coin"))
         denom = denom if denom is not None else self.denom
 
         amount_coins = [Coin(denom=denom, amount=str(amount))]
@@ -1134,7 +1177,7 @@ class _CosmosApi(LedgerApi):
 
         :return: the transaction
         """
-
+        Coin = lazy_load()["Coin"]
         if pub_keys is not None and len(pub_keys) != len(from_addresses):
             raise RuntimeError("Number of pubkeys is not equal to number of addresses")
 
@@ -1172,7 +1215,7 @@ class _CosmosApi(LedgerApi):
         account_numbers: List[int],
         from_addresses: List[str],
         chain_id: str,
-        tx_fee: List[Coin],
+        tx_fee: List[Any],  # revert to List[Coin]
         gas: int,
         memo: str,
         sequences: List[int],
@@ -1196,7 +1239,19 @@ class _CosmosApi(LedgerApi):
 
         :return: the transaction
         """
-
+        SignerInfo, ProtoPubKey, SignMode, ModeInfo, AuthInfo, Fee, TxBody, Tx = (
+            lazy_load()[k]
+            for k in (
+                "SignerInfo",
+                "ProtoPubKey",
+                "SignMode",
+                "ModeInfo",
+                "AuthInfo",
+                "Fee",
+                "TxBody",
+                "Tx",
+            )
+        )
         # Txs will fail if gas is higher than MAXIMUM_GAS_AMOUNT
         if gas > MAXIMUM_GAS_AMOUNT:
             _default_logger.warning(
@@ -1234,7 +1289,9 @@ class _CosmosApi(LedgerApi):
             single = ModeInfo.Single(mode=SignMode.SIGN_MODE_DIRECT)
             mode_info = ModeInfo(single=single)
             signer_info = SignerInfo(
-                public_key=from_pub_key_packed, mode_info=mode_info, sequence=sequence,
+                public_key=from_pub_key_packed,
+                mode_info=mode_info,
+                sequence=sequence,
             )
             signer_infos.append(signer_info)
 
@@ -1245,7 +1302,8 @@ class _CosmosApi(LedgerApi):
 
         # Prepare auth info
         auth_info = AuthInfo(
-            signer_infos=signer_infos, fee=Fee(amount=tx_fee, gas_limit=gas),
+            signer_infos=signer_infos,
+            fee=Fee(amount=tx_fee, gas_limit=gas),
         )
 
         # Prepare Tx body
@@ -1271,6 +1329,10 @@ class _CosmosApi(LedgerApi):
         :param address: the address
         :return: a tuple of account number and sequence
         """
+        QueryAccountRequest, BaseAccount = (
+            lazy_load()[k] for k in ("QueryAccountRequest", "BaseAccount")
+        )
+
         account_response = self.auth_client.Account(
             QueryAccountRequest(address=address)
         )
@@ -1293,7 +1355,9 @@ class _CosmosApi(LedgerApi):
         :param raise_on_try: whether the method will raise or log on error
         :return: tx_digest, if present
         """
-
+        Tx, BroadcastTxRequest, BroadcastMode = (
+            lazy_load()[k] for k in ("Tx", "BroadcastTxRequest", "BroadcastMode")
+        )
         tx = ParseDict(tx_signed["tx"], Tx())
 
         tx_data = tx.SerializeToString()
@@ -1335,7 +1399,7 @@ class _CosmosApi(LedgerApi):
         :param tx_digest: the digest associated to the transaction.
         :return: the tx receipt, if present
         """
-
+        GetTxRequest = lazy_load()["GetTxRequest"]
         tx_request = GetTxRequest(hash=tx_digest)
         tx_response = self.tx_client.GetTx(tx_request)
         return MessageToDict(tx_response)
@@ -1378,7 +1442,10 @@ class _CosmosApi(LedgerApi):
         )
 
     def contract_method_call(
-        self, contract_instance: Any, method_name: str, **method_args: Any,
+        self,
+        contract_instance: Any,
+        method_name: str,
+        **method_args: Any,
     ) -> Optional[JSONLike]:
         """Call a contract's method
 
@@ -1555,7 +1622,10 @@ class CosmosFaucetApi(FaucetApi):
         if "txStatus" in data["claim"]:
             tx_digest = data["claim"]["txStatus"]["hash"]
 
-        return CosmosFaucetStatus(tx_digest=tx_digest, status=data["claim"]["status"],)
+        return CosmosFaucetStatus(
+            tx_digest=tx_digest,
+            status=data["claim"]["status"],
+        )
 
     @classmethod
     def _faucet_request_uri(cls, url: Optional[str] = None) -> str:
