@@ -34,10 +34,10 @@ from aea.common import JSONLike
 _FETCHAI = "fetchai"
 _FETCH = "fetch"
 TESTNET_NAME = "testnet"
-FETCHAI_TESTNET_FAUCET_URL = "https://faucet-capricorn.t-v2-london-c.fetch-ai.com"
-DEFAULT_ADDRESS = "https://rest-capricorn.fetch.ai:443"
+FETCHAI_TESTNET_FAUCET_URL = "https://faucet-dorado.fetch.ai"
+DEFAULT_ADDRESS = "https://rest-dorado.fetch.ai:443"
 DEFAULT_CURRENCY_DENOM = "atestfet"
-DEFAULT_CHAIN_ID = "capricorn-1"
+DEFAULT_CHAIN_ID = "dorado-1"
 
 
 class FetchAIHelper(CosmosHelper):
@@ -69,7 +69,10 @@ class FetchAIApi(_CosmosApi, FetchAIHelper):
         super().__init__(**kwargs)
 
     def contract_method_call(
-        self, contract_instance: Any, method_name: str, **method_args: Any,
+        self,
+        contract_instance: Any,
+        method_name: str,
+        **method_args: Any,
     ) -> Optional[JSONLike]:
         """Call a contract's method
 
